@@ -134,7 +134,7 @@ class EntryField
   * @param text $current_value The current value to use to initialise the
   *                     field.   Optional.
   */
-  function EntryField( $intype, $inname, $attributes="", $current_value="" )
+  function __construct( $intype, $inname, $attributes="", $current_value="" )
   {
     $this->ftype = $intype;
     $this->fname = $inname;
@@ -391,7 +391,7 @@ class EntryForm
   * @param objectref $record A reference to the database object we are displaying / editing.
   * @param boolean $editmode Whether we are editing.
   */
-  function EntryForm( $action, &$record, $editing=false )
+  function __construct( $action, &$record, $editing=false )
   {
     $this->action   = $action;
     $this->record   = &$record;
