@@ -66,7 +66,7 @@ class BrowserColumn
   *     return $value;
   *   }
   */
-  function BrowserColumn( $field, $header="", $align="", $format="", $sql="", $class="", $datatype="", $hook=null ) {
+  function __construct( $field, $header="", $align="", $format="", $sql="", $class="", $datatype="", $hook=null ) {
     $this->Field  = $field;
     $this->Sql    = $sql;
     $this->Header = $header;
@@ -211,7 +211,7 @@ class Browser
   *
   * @param string $title A title for the browser (optional).
   */
-  function Browser( $title = "" ) {
+  function __construct( $title = "" ) {
     global $c;
     $this->Title = $title;
     $this->SubTitle = "";
