@@ -97,7 +97,7 @@ class iCalProp {
    *
    * @param string $propstring The string from the iCalendar which contains this property.
    */
-  function iCalProp( $propstring = null ) {
+  function __construct( $propstring = null ) {
     $this->name = "";
     $this->content = "";
     $this->parameters = array();
@@ -134,7 +134,8 @@ class iCalProp {
     $split = $this->SplitQuoted($unescaped, ':', 2);
     if (count($split) != 2) {
       // Bad things happended...
-      throw new \RuntimeException(sprintf("Couldn't parse property from string: `%s`", $propstring));
+      dbg_error_log('ERROR', "iCalendar::ParseFrom(): Couldn't parse property from string: `%s`, skipping", $unescaped);
+      return;
     }
     list($prop, $value) = $split;
 
@@ -388,7 +389,7 @@ class iCalComponent {
   /**
   * A basic constructor
   */
-  function iCalComponent( $content = null ) {
+  function __construct( $content = null ) {
     $this->type = "";
     $this->properties = array();
     $this->components = array();
