@@ -734,7 +734,7 @@
             $wrapped = "";
             foreach ($strs as $str) {
 //                print "Before: >>$str<<, len(".strlen($str).")\n";
-                $wrapped_bit = (strlen($str) == 72 ? $str : preg_replace( '/(.{72})/u', '$1'."\r\n ", $str )) .self::VEOL;
+                $wrapped_bit = (strlen($str) < 76 ? $str : preg_replace( '/(.{72})/u', '$1'."\r\n ", $str )) .self::VEOL;
 //                print "After: >>$wrapped_bit<<\n";
                 $wrapped .= $wrapped_bit;
             }
@@ -959,7 +959,12 @@
           $subfilter = $v->GetContent();
           $properties = $this->GetProperties($v->GetAttribute("name"));
           dbg_error_log( 'vCalendar', ":TestFilter: Found '%d' props of type '%s'", count($properties), $v->GetAttribute('name') );
-          $subtag = $subfilter[0]->GetNSTag();
+          if ( empty($subfilter) ) {
+            // empty means: test if a property of the type specified by the "name" attribute exists (rfc6352, 10.5.1)
+            $subtag = str_replace('prop-filter', 'is-defined', $tag);
+          } else {
+            $subtag = $subfilter[0]->GetNSTag();
+          }
           if ( $subtag == 'urn:ietf:params:xml:ns:caldav:is-not-defined'
             || $subtag == 'urn:ietf:params:xml:ns:carddav:is-not-defined' ) {
             if ( count($properties) > 0 ) {
@@ -981,7 +986,7 @@
           }
           else {
             foreach( $properties AS $kk => $property ) {
-              if ( !$property->TestFilter($subfilter) ) return false;
+              if ( !empty($subfilter) && !$property->TestFilter($subfilter) ) return false;
             }
           }
           break;
